@@ -32,16 +32,6 @@ G_BEGIN_DECLS
 
 G_DECLARE_DERIVABLE_TYPE (GeditDocument, gedit_document, GEDIT, DOCUMENT, GtkSourceBuffer)
 
-#ifdef G_OS_WIN32
-#define GEDIT_METADATA_ATTRIBUTE_POSITION "position"
-#define GEDIT_METADATA_ATTRIBUTE_ENCODING "encoding"
-#define GEDIT_METADATA_ATTRIBUTE_LANGUAGE "language"
-#else
-#define GEDIT_METADATA_ATTRIBUTE_POSITION "metadata::gedit-position"
-#define GEDIT_METADATA_ATTRIBUTE_ENCODING "metadata::gedit-encoding"
-#define GEDIT_METADATA_ATTRIBUTE_LANGUAGE "metadata::gedit-language"
-#endif
-
 struct _GeditDocumentClass
 {
 	GtkSourceBufferClass parent_class;
@@ -73,24 +63,29 @@ gchar		*gedit_document_get_uri_for_display		(GeditDocument       *doc);
 
 gchar		*gedit_document_get_short_name_for_display	(GeditDocument       *doc);
 
+G_DEPRECATED
 void		 gedit_document_set_short_name_for_display	(GeditDocument       *doc,
 								 const gchar         *short_name);
 
 gchar		*gedit_document_get_content_type		(GeditDocument       *doc);
 
+G_DEPRECATED
 void		 gedit_document_set_content_type		(GeditDocument       *doc,
 								 const gchar         *content_type);
 
 gchar		*gedit_document_get_mime_type			(GeditDocument       *doc);
 
+G_DEPRECATED_FOR (gtk_source_file_is_readonly)
 gboolean	 gedit_document_get_readonly			(GeditDocument       *doc);
 
 gboolean	 gedit_document_is_untouched			(GeditDocument       *doc);
 
 gboolean	 gedit_document_is_untitled			(GeditDocument       *doc);
 
+G_DEPRECATED_FOR (gtk_source_file_is_local)
 gboolean	 gedit_document_is_local			(GeditDocument       *doc);
 
+G_DEPRECATED
 gboolean	 gedit_document_get_deleted			(GeditDocument       *doc);
 
 gboolean	 gedit_document_goto_line			(GeditDocument       *doc,
