@@ -2,6 +2,7 @@
  * gedit-print-preview.c
  *
  * Copyright (C) 2008 Paolo Borelli
+ * Copyright (C) 2015 Sébastien Wilmet
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,22 +18,20 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gedit-print-preview.h"
 
 #include <math.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
-
 #include <cairo-pdf.h>
 
-#define PRINTER_DPI (72.)
+#define PRINTER_DPI (72.0)
 #define TOOLTIP_THRESHOLD 20
+#define PAGE_PAD 12
+#define PAGE_SHADOW_OFFSET 5
+#define ZOOM_IN_FACTOR (1.2)
+#define ZOOM_OUT_FACTOR (1.0 / ZOOM_IN_FACTOR)
 
 struct _GeditPrintPreview
 {
@@ -42,91 +41,75 @@ struct _GeditPrintPreview
 	GtkPrintContext *context;
 	GtkPrintOperationPreview *gtk_preview;
 
-	GtkWidget *next;
-	GtkButton *prev;
-	GtkWidget *page_entry;
-	GtkWidget *last;
-	GtkWidget *multi;
-	GtkWidget *zoom_one;
-	GtkWidget *zoom_fit;
-	GtkWidget *zoom_in;
-	GtkWidget *zoom_out;
-	GtkWidget *close;
+	GtkButton *prev_button;
+	GtkButton *next_button;
+	GtkEntry *page_entry;
+	GtkLabel *last_page_label;
+	GtkButton *multi_pages_button;
+	GtkButton *zoom_one_button;
+	GtkButton *zoom_fit_button;
+	GtkButton *zoom_in_button;
+	GtkButton *zoom_out_button;
+	GtkButton *close_button;
 
-	GtkWidget *layout;
+	/* The GtkLayout is where the pages are drawn. The layout should have
+	 * the focus, because key-press-events and scroll-events are handled on
+	 * the layout. It is AFAIK not easily possible to handle those events on
+	 * the GeditPrintPreview itself because when a toolbar item has the
+	 * focus, some key presses (like the arrows) moves the focus to a
+	 * sibling toolbar item instead.
+	 */
+	GtkLayout *layout;
 
-	/* real size of the page in inches */
-	double paper_w;
-	double paper_h;
-	double dpi;
-
-	double scale;
-
-	/* size of the tile of a page (including padding
-	 * and drop shadow) in pixels */
-	gint tile_w;
-	gint tile_h;
+	gdouble scale;
 
 	/* multipage support */
-	gint rows;
-	gint cols;
+	gint n_columns;
+
+	/* FIXME: handle correctly page selection (e.g. print only
+	 * page 1-3, 7 and 12.
+	 */
+	guint cur_page; /* starts at 0 */
 
-	guint n_pages;
-	guint cur_page;
 	gint cursor_x;
 	gint cursor_y;
 
-	gboolean has_tooltip;
+	guint has_tooltip : 1;
 };
 
 G_DEFINE_TYPE (GeditPrintPreview, gedit_print_preview, GTK_TYPE_GRID)
 
 static void
-gedit_print_preview_get_property (GObject    *object,
-				  guint       prop_id,
-				  GValue     *value,
-				  GParamSpec *pspec)
+gedit_print_preview_dispose (GObject *object)
 {
-	/* GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object); */
+	GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object);
 
-	switch (prop_id)
+	if (preview->gtk_preview != NULL)
 	{
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-			break;
+		GtkPrintOperationPreview *gtk_preview;
+
+		/* Set preview->gtk_preview to NULL because when calling
+		 * end_preview() this dispose() function can be run a second
+		 * time.
+		 */
+		gtk_preview = preview->gtk_preview;
+		preview->gtk_preview = NULL;
+
+		gtk_print_operation_preview_end_preview (gtk_preview);
+
+		g_object_unref (gtk_preview);
 	}
-}
 
-static void
-gedit_print_preview_set_property (GObject      *object,
-				  guint	        prop_id,
-				  const GValue *value,
-				  GParamSpec   *pspec)
-{
-	/* GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object); */
+	g_clear_object (&preview->operation);
+	g_clear_object (&preview->context);
 
-	switch (prop_id)
-	{
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-			break;
-	}
-}
-
-static void
-gedit_print_preview_finalize (GObject *object)
-{
-	/* GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (object); */
-
-	G_OBJECT_CLASS (gedit_print_preview_parent_class)->finalize (object);
+	G_OBJECT_CLASS (gedit_print_preview_parent_class)->dispose (object);
 }
 
 static void
 gedit_print_preview_grab_focus (GtkWidget *widget)
 {
-	GeditPrintPreview *preview;
-
-	preview = GEDIT_PRINT_PREVIEW (widget);
+	GeditPrintPreview *preview = GEDIT_PRINT_PREVIEW (widget);
 
 	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
@@ -134,34 +117,115 @@ gedit_print_preview_grab_focus (GtkWidget *widget)
 static void
 gedit_print_preview_class_init (GeditPrintPreviewClass *klass)
 {
-	GObjectClass *object_class;
-	GtkWidgetClass *widget_class;
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	object_class = G_OBJECT_CLASS (klass);
-	widget_class = GTK_WIDGET_CLASS (klass);
-
-	object_class->get_property = gedit_print_preview_get_property;
-	object_class->set_property = gedit_print_preview_set_property;
-	object_class->finalize = gedit_print_preview_finalize;
+	object_class->dispose = gedit_print_preview_dispose;
 
 	widget_class->grab_focus = gedit_print_preview_grab_focus;
 
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-print-preview.ui");
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, prev);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, next);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, multi);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, prev_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, next_button);
 	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, page_entry);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, last);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_one);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_fit);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_in);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_out);
-	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, close);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, last_page_label);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, multi_pages_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_one_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_fit_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_in_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, zoom_out_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, close_button);
 	gtk_widget_class_bind_template_child (widget_class, GeditPrintPreview, layout);
 }
 
+static gint
+get_n_pages (GeditPrintPreview *preview)
+{
+	gint n_pages;
+
+	g_object_get (preview->operation, "n-pages", &n_pages, NULL);
+
+	return n_pages;
+}
+
+static gdouble
+get_screen_dpi (GeditPrintPreview *preview)
+{
+	GdkScreen *screen;
+	gdouble dpi;
+	static gboolean warning_shown = FALSE;
+
+	screen = gtk_widget_get_screen (GTK_WIDGET (preview));
+
+	if (screen == NULL)
+	{
+		return PRINTER_DPI;
+	}
+
+	dpi = gdk_screen_get_resolution (screen);
+	if (dpi < 30.0 || 600.0 < dpi)
+	{
+		if (!warning_shown)
+		{
+			g_warning ("Invalid the x-resolution for the screen, assuming 96dpi");
+			warning_shown = TRUE;
+		}
+
+		dpi = 96.0;
+	}
+
+	return dpi;
+}
+
+/* Get the paper size in points: these must be used only
+ * after the widget has been mapped and the dpi is known.
+ */
+static gdouble
+get_paper_width (GeditPrintPreview *preview)
+{
+	GtkPageSetup *page_setup;
+	gdouble paper_width;
+
+	page_setup = gtk_print_context_get_page_setup (preview->context);
+	paper_width = gtk_page_setup_get_paper_width (page_setup, GTK_UNIT_INCH);
+
+	return paper_width * get_screen_dpi (preview);
+}
+
+static gdouble
+get_paper_height (GeditPrintPreview *preview)
+{
+	GtkPageSetup *page_setup;
+	gdouble paper_height;
+
+	page_setup = gtk_print_context_get_page_setup (preview->context);
+	paper_height = gtk_page_setup_get_paper_height (page_setup, GTK_UNIT_INCH);
+
+	return paper_height * get_screen_dpi (preview);
+}
+
+/* The tile size is the size in pixels of the area where a page will be
+ * drawn, including the padding. The size is independent of the
+ * orientation.
+ */
+static void
+get_tile_size (GeditPrintPreview *preview,
+	       gint              *tile_width,
+	       gint              *tile_height)
+{
+	if (tile_width != NULL)
+	{
+		*tile_width = 2 * PAGE_PAD + round (preview->scale * get_paper_width (preview));
+	}
+
+	if (tile_height != NULL)
+	{
+		*tile_height = 2 * PAGE_PAD + round (preview->scale * get_paper_height (preview));
+	}
+}
+
 static void
 get_adjustments (GeditPrintPreview  *preview,
 		 GtkAdjustment     **hadj,
@@ -174,71 +238,28 @@ get_adjustments (GeditPrintPreview  *preview,
 static void
 update_layout_size (GeditPrintPreview *preview)
 {
+	gint tile_width;
+	gint tile_height;
+
+	get_tile_size (preview, &tile_width, &tile_height);
+
 	/* force size of the drawing area to make the scrolled window work */
-	gtk_layout_set_size (GTK_LAYOUT (preview->layout),
-	                     preview->tile_w * preview->cols,
-	                     preview->tile_h * preview->rows);
+	gtk_layout_set_size (preview->layout,
+	                     tile_width * preview->n_columns,
+	                     tile_height);
 
-	gtk_widget_queue_draw (preview->layout);
-}
-
-static void
-set_rows_and_cols (GeditPrintPreview *preview,
-		   gint	              rows,
-		   gint	              cols)
-{
-	/* TODO: set the zoom appropriately */
-
-	preview->rows = rows;
-	preview->cols = cols;
-	update_layout_size (preview);
-}
-
-/* get the paper size in points: these must be used only
- * after the widget has been mapped and the dpi is known */
-
-static double
-get_paper_width (GeditPrintPreview *preview)
-{
-	return preview->paper_w * preview->dpi;
-}
-
-static double
-get_paper_height (GeditPrintPreview *preview)
-{
-	return preview->paper_h * preview->dpi;
-}
-
-#define PAGE_PAD 12
-#define PAGE_SHADOW_OFFSET 5
-
-/* The tile size is the size of the area where a page
- * will be drawn including the padding and idependent
- * of the orientation */
-
-/* updates the tile size to the current zoom and page size */
-static void
-update_tile_size (GeditPrintPreview *preview)
-{
-	gint w, h;
-
-	w = 2 * PAGE_PAD + floor (preview->scale * get_paper_width (preview) + 0.5);
-	h = 2 * PAGE_PAD + floor (preview->scale * get_paper_height (preview) + 0.5);
-
-	preview->tile_w = w;
-	preview->tile_h = h;
+	gtk_widget_queue_draw (GTK_WIDGET (preview->layout));
 }
 
 /* Zoom should always be set with one of these two function
- * so that the tile size is properly updated */
+ * so that the tile size is properly updated.
+ */
 
 static void
 set_zoom_factor (GeditPrintPreview *preview,
-                 double            zoom)
+		 gdouble            zoom)
 {
 	preview->scale = zoom;
-
-	update_tile_size (preview);
 	update_layout_size (preview);
 }
 
@@ -246,43 +267,26 @@ static void
 set_zoom_fit_to_size (GeditPrintPreview *preview)
 {
 	GtkAdjustment *hadj, *vadj;
-	double width, height;
-	double p_width, p_height;
-	double zoomx, zoomy;
+	gdouble width, height;
+	gdouble paper_width, paper_height;
+	gdouble zoomx, zoomy;
 
 	get_adjustments (preview, &hadj, &vadj);
 
-	g_object_get (hadj, "page-size", &width, NULL);
-	g_object_get (vadj, "page-size", &height, NULL);
+	width = gtk_adjustment_get_page_size (hadj);
+	height = gtk_adjustment_get_page_size (vadj);
 
-	width /= preview->cols;
-	height /= preview->rows;
+	width /= preview->n_columns;
 
-	p_width = get_paper_width (preview);
-	p_height = get_paper_height (preview);
+	paper_width = get_paper_width (preview);
+	paper_height = get_paper_height (preview);
 
-	zoomx = MAX (1, width - 2 * PAGE_PAD) / p_width;
-	zoomy = MAX (1, height - 2 * PAGE_PAD) / p_height;
+	zoomx = MAX (1, width - 2 * PAGE_PAD) / paper_width;
+	zoomy = MAX (1, height - 2 * PAGE_PAD) / paper_height;
 
-	if (zoomx <= zoomy)
-	{
-		preview->tile_w = width;
-		preview->tile_h = floor (0.5 + width * (p_height / p_width));
-		preview->scale = zoomx;
-	}
-	else
-	{
-		preview->tile_w = floor (0.5 + height * (p_width / p_height));
-		preview->tile_h = height;
-		preview->scale = zoomy;
-	}
-
-	update_layout_size (preview);
+	set_zoom_factor (preview, zoomx <= zoomy ? zoomx : zoomy);
 }
 
-#define ZOOM_IN_FACTOR (1.2)
-#define ZOOM_OUT_FACTOR (1.0 / ZOOM_IN_FACTOR)
-
 static void
 zoom_in (GeditPrintPreview *preview)
 {
@@ -299,23 +303,29 @@ static void
 goto_page (GeditPrintPreview *preview,
            gint               page)
 {
-	gchar c[32];
+	gchar *page_str;
+	gint n_pages;
 
-	g_snprintf (c, 32, "%d", page + 1);
-	gtk_entry_set_text (GTK_ENTRY (preview->page_entry), c);
+	page_str = g_strdup_printf ("%d", page + 1);
+	gtk_entry_set_text (preview->page_entry, page_str);
+	g_free (page_str);
 
-	gtk_widget_set_sensitive (GTK_WIDGET (preview->prev),
-	                          (page > 0) && (preview->n_pages > 1));
-	gtk_widget_set_sensitive (GTK_WIDGET (preview->next),
-	                          (page != (preview->n_pages - 1)) &&
-	                          (preview->n_pages > 1));
+	n_pages = get_n_pages (preview);
+
+	gtk_widget_set_sensitive (GTK_WIDGET (preview->prev_button),
+	                          page > 0 &&
+				  n_pages > 1);
+
+	gtk_widget_set_sensitive (GTK_WIDGET (preview->next_button),
+	                          page < (n_pages - 1) &&
+	                          n_pages > 1);
 
 	if (page != preview->cur_page)
 	{
 		preview->cur_page = page;
-		if (preview->n_pages > 0)
+		if (n_pages > 0)
 		{
-			gtk_widget_queue_draw (preview->layout);
+			gtk_widget_queue_draw (GTK_WIDGET (preview->layout));
 		}
 	}
 }
@@ -335,11 +345,13 @@ prev_button_clicked (GtkWidget         *button,
 	}
 	else
 	{
-		page = preview->cur_page - preview->rows * preview->cols;
+		page = preview->cur_page - preview->n_columns;
 	}
 
 	goto_page (preview, MAX (page, 0));
 
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
+
 	gdk_event_free (event);
 }
 
@@ -349,19 +361,22 @@ next_button_clicked (GtkWidget         *button,
 {
 	GdkEvent *event;
 	gint page;
+	gint n_pages = get_n_pages (preview);
 
 	event = gtk_get_current_event ();
 
 	if (event->button.state & GDK_SHIFT_MASK)
 	{
-		page = preview->n_pages - 1;
+		page = n_pages - 1;
 	}
 	else
 	{
-		page = preview->cur_page + preview->rows * preview->cols;
+		page = preview->cur_page + preview->n_columns;
 	}
 
-	goto_page (preview, MIN (page, preview->n_pages - 1));
+	goto_page (preview, MIN (page, n_pages - 1));
+
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 
 	gdk_event_free (event);
 }
@@ -372,10 +387,11 @@ page_entry_activated (GtkEntry          *entry,
 {
 	const gchar *text;
 	gint page;
+	gint n_pages = get_n_pages (preview);
 
 	text = gtk_entry_get_text (entry);
 
-	page = CLAMP (atoi (text), 1, preview->n_pages) - 1;
+	page = CLAMP (atoi (text), 1, n_pages) - 1;
 	goto_page (preview, page);
 
 	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
@@ -387,39 +403,30 @@ page_entry_insert_text (GtkEditable *editable,
 			gint         length,
 			gint        *position)
 {
-	gunichar c;
-	const gchar *p;
 	const gchar *end;
+	const gchar *p;
 
-	p = text;
 	end = text + length;
 
-	while (p != end)
+	for (p = text; p < end; p = g_utf8_next_char (p))
 	{
-		const gchar *next;
-		next = g_utf8_next_char (p);
-
-		c = g_utf8_get_char (p);
-
-		if (!g_unichar_isdigit (c))
+		if (!g_unichar_isdigit (g_utf8_get_char (p)))
 		{
 			g_signal_stop_emission_by_name (editable, "insert-text");
 			break;
 		}
-
-		p = next;
 	}
 }
 
 static gboolean
-page_entry_focus_out (GtkWidget         *widget,
+page_entry_focus_out (GtkEntry          *entry,
 		      GdkEventFocus     *event,
 		      GeditPrintPreview *preview)
 {
 	const gchar *text;
 	gint page;
 
-	text = gtk_entry_get_text (GTK_ENTRY (widget));
+	text = gtk_entry_get_text (entry);
 	page = atoi (text) - 1;
 
 	/* Reset the page number only if really needed */
@@ -428,75 +435,56 @@ page_entry_focus_out (GtkWidget         *widget,
 		gchar *str;
 
 		str = g_strdup_printf ("%d", preview->cur_page + 1);
-		gtk_entry_set_text (GTK_ENTRY (widget), str);
+		gtk_entry_set_text (entry, str);
 		g_free (str);
 	}
 
-	return FALSE;
+	return GDK_EVENT_PROPAGATE;
 }
 
 static void
-on_1x1_clicked (GtkMenuItem       *i,
+on_1x1_clicked (GtkMenuItem       *item,
 		GeditPrintPreview *preview)
 {
-	set_rows_and_cols (preview, 1, 1);
+	preview->n_columns = 1;
+	update_layout_size (preview);
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
-on_1x2_clicked (GtkMenuItem       *i,
+on_1x2_clicked (GtkMenuItem       *item,
 		GeditPrintPreview *preview)
 {
-	set_rows_and_cols (preview, 1, 2);
+	preview->n_columns = 2;
+	set_zoom_fit_to_size (preview);
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
-on_2x1_clicked (GtkMenuItem       *i,
-		GeditPrintPreview *preview)
+multi_pages_button_clicked (GtkWidget         *button,
+			    GeditPrintPreview *preview)
 {
-	set_rows_and_cols (preview, 2, 1);
-}
+	GtkWidget *menu;
+	GtkWidget *item;
 
-static void
-on_2x2_clicked (GtkMenuItem       *i,
-		GeditPrintPreview *preview)
-{
-	set_rows_and_cols (preview, 2, 2);
-}
-
-static void
-multi_button_clicked (GtkWidget	        *button,
-		      GeditPrintPreview *preview)
-{
-	GtkWidget *m, *i;
-
-	m = gtk_menu_new ();
-	gtk_widget_show (m);
-	g_signal_connect (m,
-			 "selection_done",
+	menu = gtk_menu_new ();
+	gtk_widget_show (menu);
+	g_signal_connect (menu,
+			  "selection-done",
 			  G_CALLBACK (gtk_widget_destroy),
-			  m);
+			  NULL);
 
-	i = gtk_menu_item_new_with_label ("1x1");
-	gtk_widget_show (i);
-	gtk_menu_attach (GTK_MENU (m), i, 0, 1, 0, 1);
-	g_signal_connect (i, "activate", G_CALLBACK (on_1x1_clicked), preview);
+	item = gtk_menu_item_new_with_label ("1x1");
+	gtk_widget_show (item);
+	gtk_menu_attach (GTK_MENU (menu), item, 0, 1, 0, 1);
+	g_signal_connect (item, "activate", G_CALLBACK (on_1x1_clicked), preview);
 
-	i = gtk_menu_item_new_with_label ("2x1");
-	gtk_widget_show (i);
-	gtk_menu_attach (GTK_MENU (m), i, 0, 1, 1, 2);
-	g_signal_connect (i, "activate", G_CALLBACK (on_2x1_clicked), preview);
+	item = gtk_menu_item_new_with_label ("1x2");
+	gtk_widget_show (item);
+	gtk_menu_attach (GTK_MENU (menu), item, 1, 2, 0, 1);
+	g_signal_connect (item, "activate", G_CALLBACK (on_1x2_clicked), preview);
 
-	i = gtk_menu_item_new_with_label ("1x2");
-	gtk_widget_show (i);
-	gtk_menu_attach (GTK_MENU (m), i, 1, 2, 0, 1);
-	g_signal_connect (i, "activate", G_CALLBACK (on_1x2_clicked), preview);
-
-	i = gtk_menu_item_new_with_label ("2x2");
-	gtk_widget_show (i);
-	gtk_menu_attach (GTK_MENU (m), i, 1, 2, 1, 2);
-	g_signal_connect (i, "activate", G_CALLBACK (on_2x2_clicked), preview);
-
-	gtk_menu_popup (GTK_MENU (m),
+	gtk_menu_popup (GTK_MENU (menu),
 			NULL, NULL, NULL, preview, 0,
 			GDK_CURRENT_TIME);
 }
@@ -506,6 +494,7 @@ zoom_one_button_clicked (GtkWidget         *button,
 			 GeditPrintPreview *preview)
 {
 	set_zoom_factor (preview, 1);
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
@@ -513,6 +502,7 @@ zoom_fit_button_clicked (GtkWidget         *button,
 			 GeditPrintPreview *preview)
 {
 	set_zoom_fit_to_size (preview);
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
@@ -520,6 +510,7 @@ zoom_in_button_clicked (GtkWidget         *button,
 			GeditPrintPreview *preview)
 {
 	zoom_in (preview);
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
@@ -527,6 +518,7 @@ zoom_out_button_clicked (GtkWidget         *button,
 			 GeditPrintPreview *preview)
 {
 	zoom_out (preview);
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
@@ -565,41 +557,49 @@ scroll_event_activated (GtkWidget         *widget,
 static gint
 get_first_page_displayed (GeditPrintPreview *preview)
 {
-	return preview->cur_page - preview->cur_page % (preview->cols * preview->rows);
+	return preview->cur_page - (preview->cur_page % preview->n_columns);
 }
 
-/* returns the page number (starting from 0) or -1 if no page */
+/* Returns the page number (starting from 0) or -1 if no page. */
 static gint
 get_page_at_coords (GeditPrintPreview *preview,
                     gint               x,
                     gint               y)
 {
+	gint tile_width, tile_height;
 	GtkAdjustment *hadj, *vadj;
-	gint r, c, pg;
+	gint col, page;
 
-	if (preview->tile_h <= 0 || preview->tile_w <= 0)
+	get_tile_size (preview, &tile_width, &tile_height);
+
+	if (tile_height <= 0 || tile_width <= 0)
+	{
 		return -1;
+	}
 
 	get_adjustments (preview, &hadj, &vadj);
 
 	x += gtk_adjustment_get_value (hadj);
 	y += gtk_adjustment_get_value (vadj);
 
-	r = 1 + y / (preview->tile_h);
-	c = 1 + x / (preview->tile_w);
+	col = x / tile_width;
 
-	if (c > preview->cols)
+	if (col >= preview->n_columns || y > tile_height)
+	{
 		return -1;
+	}
 
-	pg = get_first_page_displayed (preview) - 1;
-	pg += (r - 1) * preview->cols + c;
+	page = get_first_page_displayed (preview) + col;
 
-	if (pg >= preview->n_pages)
+	if (page >= get_n_pages (preview))
+	{
 		return -1;
+	}
 
-	/* FIXME: we could try to be picky and check
-	 * if we actually are inside the page */
-	return pg;
+	/* FIXME: we could try to be picky and check if we actually are inside
+	 * the page (i.e. not in the padding or shadow).
+	 */
+	return page;
 }
 
 static gboolean
@@ -639,16 +639,21 @@ preview_layout_query_tooltip (GtkWidget         *widget,
 			      GtkTooltip        *tooltip,
 			      GeditPrintPreview *preview)
 {
-	gint pg;
-	gchar *tip;
-
-	if (preview->has_tooltip == TRUE)
+	if (preview->has_tooltip)
 	{
-		pg = get_page_at_coords (preview, x, y);
-		if (pg < 0)
+		gint page;
+		gchar *tip;
+
+		page = get_page_at_coords (preview, x, y);
+		if (page < 0)
+		{
 			return FALSE;
+		}
+
+		tip = g_strdup_printf (_("Page %d of %d"),
+				       page + 1,
+				       get_n_pages (preview));
 
-		tip = g_strdup_printf (_("Page %d of %d"), pg + 1, preview->n_pages);
 		gtk_tooltip_set_text (tooltip, tip);
 		g_free (tip);
 
@@ -667,80 +672,87 @@ preview_layout_key_press (GtkWidget         *widget,
 			  GeditPrintPreview *preview)
 {
 	GtkAdjustment *hadj, *vadj;
-	double x, y;
-	guint h, w;
-	double hlower, hupper, vlower, vupper;
-	double hpage, vpage;
-	double hstep, vstep;
-	gboolean domove = FALSE;
-	gboolean ret = TRUE;
+	gdouble x, y;
+	gdouble hlower, vlower;
+	gdouble hupper, vupper;
+	gdouble visible_width, visible_height;
+	gdouble hstep, vstep;
+	gint n_pages;
+	gboolean do_move = FALSE;
 
 	get_adjustments (preview, &hadj, &vadj);
 
 	x = gtk_adjustment_get_value (hadj);
 	y = gtk_adjustment_get_value (vadj);
 
-	g_object_get (hadj,
-		      "lower", &hlower,
-		      "upper", &hupper,
-		      "page-size", &hpage,
-		      NULL);
-	g_object_get (vadj,
-		      "lower", &vlower,
-		      "upper", &vupper,
-		      "page-size", &vpage,
-		      NULL);
+	hlower = gtk_adjustment_get_lower (hadj);
+	vlower = gtk_adjustment_get_lower (vadj);
 
-	gtk_layout_get_size (GTK_LAYOUT (preview->layout), &w, &h);
+	hupper = gtk_adjustment_get_upper (hadj);
+	vupper = gtk_adjustment_get_upper (vadj);
+
+	visible_width = gtk_adjustment_get_page_size (hadj);
+	visible_height = gtk_adjustment_get_page_size (vadj);
 
 	hstep = 10;
 	vstep = 10;
 
+	n_pages = get_n_pages (preview);
+
 	switch (event->keyval)
 	{
 		case '1':
 			set_zoom_fit_to_size (preview);
 			break;
+
 		case '+':
 		case '=':
 		case GDK_KEY_KP_Add:
 			zoom_in (preview);
 			break;
+
 		case '-':
 		case '_':
 		case GDK_KEY_KP_Subtract:
 			zoom_out (preview);
 			break;
+
 		case GDK_KEY_KP_Right:
 		case GDK_KEY_Right:
 			if (event->state & GDK_SHIFT_MASK)
-				x = hupper - hpage;
+				x = hupper - visible_width;
 			else
-				x = MIN (hupper - hpage, x + hstep);
-			domove = TRUE;
+				x = MIN (hupper - visible_width, x + hstep);
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_Left:
 		case GDK_KEY_Left:
 			if (event->state & GDK_SHIFT_MASK)
 				x = hlower;
 			else
 				x = MAX (hlower, x - hstep);
-			domove = TRUE;
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_Up:
 		case GDK_KEY_Up:
 			if (event->state & GDK_SHIFT_MASK)
 				goto page_up;
+
 			y = MAX (vlower, y - vstep);
-			domove = TRUE;
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_Down:
 		case GDK_KEY_Down:
 			if (event->state & GDK_SHIFT_MASK)
 				goto page_down;
-			y = MIN (vupper - vpage, y + vstep);
-			domove = TRUE;
+
+			y = MIN (vupper - visible_height, y + vstep);
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_Page_Up:
 		case GDK_KEY_Page_Up:
 		case GDK_KEY_Delete:
@@ -752,22 +764,23 @@ preview_layout_key_press (GtkWidget         *widget,
 				if (preview->cur_page > 0)
 				{
 					goto_page (preview, preview->cur_page - 1);
-					y = (vupper - vpage);
+					y = (vupper - visible_height);
 				}
 			}
 			else
 			{
 				y = vlower;
 			}
-			domove = TRUE;
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_Page_Down:
 		case GDK_KEY_Page_Down:
 		case ' ':
 		page_down:
-			if (y >= (vupper - vpage))
+			if (y >= (vupper - visible_height))
 			{
-				if (preview->cur_page < preview->n_pages - 1)
+				if (preview->cur_page < n_pages - 1)
 				{
 					goto_page (preview, preview->cur_page + 1);
 					y = vlower;
@@ -775,117 +788,126 @@ preview_layout_key_press (GtkWidget         *widget,
 			}
 			else
 			{
-				y = (vupper - vpage);
+				y = (vupper - visible_height);
 			}
-			domove = TRUE;
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_Home:
 		case GDK_KEY_Home:
 			goto_page (preview, 0);
-			y = 0;
-			domove = TRUE;
+			y = vlower;
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_KP_End:
 		case GDK_KEY_End:
-			goto_page (preview, preview->n_pages - 1);
-			y = 0;
-			domove = TRUE;
+			goto_page (preview, n_pages - 1);
+			y = vlower;
+			do_move = TRUE;
 			break;
+
 		case GDK_KEY_Escape:
 			gtk_widget_destroy (GTK_WIDGET (preview));
 			break;
-		case 'c':
-			if (event->state & GDK_MOD1_MASK)
-			{
-				gtk_widget_destroy (GTK_WIDGET (preview));
-			}
-			break;
+
 		case 'p':
 			if (event->state & GDK_MOD1_MASK)
 			{
-				gtk_widget_grab_focus (preview->page_entry);
+				gtk_widget_grab_focus (GTK_WIDGET (preview->page_entry));
 			}
 			break;
+
 		default:
-			/* by default do not stop the default handler */
-			ret = FALSE;
+			return GDK_EVENT_PROPAGATE;
 	}
 
-	if (domove)
+	if (do_move)
 	{
 		gtk_adjustment_set_value (hadj, x);
 		gtk_adjustment_set_value (vadj, y);
-
-		gtk_adjustment_value_changed (hadj);
-		gtk_adjustment_value_changed (vadj);
 	}
 
-	return ret;
+	return GDK_EVENT_STOP;
 }
 
 static void
 gedit_print_preview_init (GeditPrintPreview *preview)
 {
-	preview->operation = NULL;
-	preview->context = NULL;
-	preview->gtk_preview = NULL;
+	preview->cur_page = 0;
+	preview->scale = 1.0;
+	preview->n_columns = 1;
+	preview->cursor_x = 0;
+	preview->cursor_y = 0;
+	preview->has_tooltip = TRUE;
 
 	gtk_widget_init_template (GTK_WIDGET (preview));
 
-	g_signal_connect (preview->prev,
+	g_signal_connect (preview->prev_button,
 			  "clicked",
 			  G_CALLBACK (prev_button_clicked),
 			  preview);
-	g_signal_connect (preview->next,
+
+	g_signal_connect (preview->next_button,
 			  "clicked",
 			  G_CALLBACK (next_button_clicked),
 			  preview);
+
 	g_signal_connect (preview->page_entry,
 			  "activate",
 			  G_CALLBACK (page_entry_activated),
 			  preview);
+
 	g_signal_connect (preview->page_entry,
 			  "insert-text",
 			  G_CALLBACK (page_entry_insert_text),
 			  NULL);
+
 	g_signal_connect (preview->page_entry,
 			  "focus-out-event",
 			  G_CALLBACK (page_entry_focus_out),
 			  preview);
-	g_signal_connect (preview->multi,
+
+	g_signal_connect (preview->multi_pages_button,
 			  "clicked",
-			  G_CALLBACK (multi_button_clicked),
+			  G_CALLBACK (multi_pages_button_clicked),
 			  preview);
-	g_signal_connect (preview->zoom_one,
+
+	g_signal_connect (preview->zoom_one_button,
 			  "clicked",
 			  G_CALLBACK (zoom_one_button_clicked),
 			  preview);
-	g_signal_connect (preview->zoom_fit,
+
+	g_signal_connect (preview->zoom_fit_button,
 			  "clicked",
 			  G_CALLBACK (zoom_fit_button_clicked),
 			  preview);
-	g_signal_connect (preview->zoom_in,
+
+	g_signal_connect (preview->zoom_in_button,
 			  "clicked",
 			  G_CALLBACK (zoom_in_button_clicked),
 			  preview);
-	g_signal_connect (preview->zoom_out,
+
+	g_signal_connect (preview->zoom_out_button,
 			  "clicked",
 			  G_CALLBACK (zoom_out_button_clicked),
 			  preview);
-	g_signal_connect (preview->close,
+
+	g_signal_connect (preview->close_button,
 			  "clicked",
 			  G_CALLBACK (close_button_clicked),
 			  preview);
 
-	g_object_set (preview->layout, "has-tooltip", TRUE, NULL);
 	g_signal_connect (preview->layout,
 			  "query-tooltip",
 			  G_CALLBACK (preview_layout_query_tooltip),
 			  preview);
+
 	g_signal_connect (preview->layout,
 			  "key-press-event",
 			  G_CALLBACK (preview_layout_key_press),
 			  preview);
+
 	g_signal_connect (preview->layout,
 			  "scroll-event",
 			  G_CALLBACK (scroll_event_activated),
@@ -896,32 +918,22 @@ gedit_print_preview_init (GeditPrintPreview *preview)
 			  "motion-notify-event",
 			  G_CALLBACK (on_preview_layout_motion_notify),
 			  preview);
-	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 
-	preview->cur_page = 0;
-	preview->paper_w = 0;
-	preview->paper_h = 0;
-	preview->dpi = PRINTER_DPI;
-	preview->scale = 1.0;
-	preview->rows = 1;
-	preview->cols = 1;
-	preview->cursor_x = 0;
-	preview->cursor_y = 0;
-	preview->has_tooltip = TRUE;
+	gtk_widget_grab_focus (GTK_WIDGET (preview->layout));
 }
 
 static void
-draw_page_content (cairo_t            *cr,
-		   gint	               page_number,
-		   GeditPrintPreview  *preview)
+draw_page_content (cairo_t           *cr,
+		   gint               page_number,
+		   GeditPrintPreview *preview)
 {
+	gdouble dpi;
+
 	/* scale to the desired size */
 	cairo_scale (cr, preview->scale, preview->scale);
 
-	gtk_print_context_set_cairo_context (preview->context,
-	                                     cr,
-	                                     preview->dpi,
-	                                     preview->dpi);
+	dpi = get_screen_dpi (preview);
+	gtk_print_context_set_cairo_context (preview->context, cr, dpi, dpi);
 
 	gtk_print_operation_preview_render_page (preview->gtk_preview,
 	                                         page_number);
@@ -930,31 +942,30 @@ draw_page_content (cairo_t            *cr,
 /* For the frame, we scale and rotate manually, since
  * the line width should not depend on the zoom and
  * the drop shadow should be on the bottom right no matter
- * the orientation */
+ * the orientation.
+ */
 static void
-draw_page_frame (cairo_t            *cr,
-		 GeditPrintPreview  *preview)
+draw_page_frame (cairo_t           *cr,
+		 GeditPrintPreview *preview)
 {
-	double w, h;
+	gdouble width;
+	gdouble height;
 
-	w = get_paper_width (preview);
-	h = get_paper_height (preview);
-
-	w *= preview->scale;
-	h *= preview->scale;
+	width = get_paper_width (preview) * preview->scale;
+	height = get_paper_height (preview) * preview->scale;
 
 	/* drop shadow */
 	cairo_set_source_rgb (cr, 0, 0, 0);
 	cairo_rectangle (cr,
 			 PAGE_SHADOW_OFFSET, PAGE_SHADOW_OFFSET,
-			 w, h);
+			 width, height);
 	cairo_fill (cr);
 
 	/* page frame */
 	cairo_set_source_rgb (cr, 1, 1, 1);
 	cairo_rectangle (cr,
 			 0, 0,
-			 w, h);
+			 width, height);
 	cairo_fill_preserve (cr);
 	cairo_set_source_rgb (cr, 0, 0, 0);
 	cairo_set_line_width (cr, 1);
@@ -963,9 +974,9 @@ draw_page_frame (cairo_t            *cr,
 
 static void
 draw_page (cairo_t           *cr,
-	   double             x,
-	   double             y,
-	   gint	              page_number,
+	   gdouble            x,
+	   gdouble            y,
+	   gint               page_number,
 	   GeditPrintPreview *preview)
 {
 	cairo_save (cr);
@@ -985,80 +996,58 @@ preview_draw (GtkWidget         *widget,
 	      GeditPrintPreview *preview)
 {
 	GdkWindow *bin_window;
-	gint pg;
-	gint i, j;
+	gint tile_width;
+	gint page_num;
+	gint n_pages;
+	gint col;
 
-	bin_window = gtk_layout_get_bin_window (GTK_LAYOUT (preview->layout));
+	bin_window = gtk_layout_get_bin_window (preview->layout);
 
-	if (gtk_cairo_should_draw_window (cr, bin_window))
+	if (!gtk_cairo_should_draw_window (cr, bin_window))
 	{
-		cairo_save (cr);
+		return GDK_EVENT_STOP;
+	}
 
-		gtk_cairo_transform_to_window (cr, widget, bin_window);
+	cairo_save (cr);
 
-		/* get the first page to display */
-		pg = get_first_page_displayed (preview);
+	gtk_cairo_transform_to_window (cr, widget, bin_window);
 
-		for (i = 0; i < preview->cols; ++i)
+	get_tile_size (preview, &tile_width, NULL);
+	n_pages = get_n_pages (preview);
+
+	col = 0;
+	page_num = get_first_page_displayed (preview);
+
+	while (col < preview->n_columns && page_num < n_pages)
+	{
+		if (!gtk_print_operation_preview_is_selected (preview->gtk_preview, page_num))
 		{
-			for (j = 0; j < preview->rows; ++j)
-			{
-				if (!gtk_print_operation_preview_is_selected (preview->gtk_preview, pg))
-				{
-					continue;
-				}
-
-				if (pg == preview->n_pages)
-				{
-					break;
-				}
-
-				draw_page (cr,
-					   j * preview->tile_w,
-					   i * preview->tile_h,
-					   pg,
-					   preview);
-
-				++pg;
-			}
+			page_num++;
+			continue;
 		}
 
-		cairo_restore (cr);
+		draw_page (cr,
+			   col * tile_width,
+			   0,
+			   page_num,
+			   preview);
+
+		col++;
+		page_num++;
 	}
 
-	return TRUE;
-}
+	cairo_restore (cr);
 
-static double
-get_screen_dpi (GeditPrintPreview *preview)
-{
-	GdkScreen *screen;
-	double dpi;
-
-	screen = gtk_widget_get_screen (GTK_WIDGET (preview));
-
-	dpi = gdk_screen_get_resolution (screen);
-	if (dpi < 30. || 600. < dpi)
-	{
-		g_warning ("Invalid the x-resolution for the screen, assuming 96dpi");
-		dpi = 96.;
-	}
-
-	return dpi;
+	return GDK_EVENT_STOP;
 }
 
 static void
-set_n_pages (GeditPrintPreview *preview,
-	     gint               n_pages)
+init_last_page_label (GeditPrintPreview *preview)
 {
 	gchar *str;
 
-	preview->n_pages = n_pages;
-
-	/* FIXME: count the visible pages */
-
-	str =  g_strdup_printf ("%d", n_pages);
-	gtk_label_set_markup (GTK_LABEL (preview->last), str);
+	str = g_strdup_printf ("%d", get_n_pages (preview));
+	gtk_label_set_text (preview->last_page_label, str);
 	g_free (str);
 }
 
@@ -1067,15 +1056,9 @@ preview_ready (GtkPrintOperationPreview *gtk_preview,
 	       GtkPrintContext          *context,
 	       GeditPrintPreview        *preview)
 {
-	gint n_pages;
-
-	g_object_get (preview->operation, "n-pages", &n_pages, NULL);
-	set_n_pages (preview, n_pages);
+	init_last_page_label (preview);
 	goto_page (preview, 0);
 
-	/* figure out the dpi */
-	preview->dpi = get_screen_dpi (preview);
-
 	set_zoom_factor (preview, 1.0);
 
 	/* let the default gtklayout handler clear the background */
@@ -1084,24 +1067,7 @@ preview_ready (GtkPrintOperationPreview *gtk_preview,
 				G_CALLBACK (preview_draw),
 				preview);
 
-	gtk_widget_queue_draw (preview->layout);
-}
-
-static void
-update_paper_size (GeditPrintPreview *preview,
-		   GtkPageSetup      *page_setup)
-{
-	preview->paper_w = gtk_page_setup_get_paper_width (page_setup, GTK_UNIT_INCH);
-	preview->paper_h = gtk_page_setup_get_paper_height (page_setup, GTK_UNIT_INCH);
-}
-
-static void
-preview_got_page_size (GtkPrintOperationPreview *gtk_preview,
-		       GtkPrintContext          *context,
-		       GtkPageSetup             *page_setup,
-		       GeditPrintPreview        *preview)
-{
-	update_paper_size (preview, page_setup);
+	gtk_widget_queue_draw (GTK_WIDGET (preview->layout));
 }
 
 /* HACK: we need a dummy surface to paginate... can we use something simpler? */
@@ -1114,78 +1080,74 @@ dummy_write_func (G_GNUC_UNUSED gpointer      closure,
 	return CAIRO_STATUS_SUCCESS;
 }
 
-#define PRINTER_DPI (72.)
-
 static cairo_surface_t *
 create_preview_surface_platform (GtkPaperSize *paper_size,
-				 double       *dpi_x,
-				 double       *dpi_y)
+				 gdouble      *dpi_x,
+				 gdouble      *dpi_y)
 {
-	double width, height;
-	cairo_surface_t *sf;
+	gdouble width, height;
 
 	width = gtk_paper_size_get_width (paper_size, GTK_UNIT_POINTS);
 	height = gtk_paper_size_get_height (paper_size, GTK_UNIT_POINTS);
 
 	*dpi_x = *dpi_y = PRINTER_DPI;
 
-	sf = cairo_pdf_surface_create_for_stream (dummy_write_func, NULL,
-						  width, height);
-
-	return sf;
+	return cairo_pdf_surface_create_for_stream (dummy_write_func, NULL,
+						    width, height);
 }
 
 static cairo_surface_t *
 create_preview_surface (GeditPrintPreview *preview,
-			double            *dpi_x,
-			double            *dpi_y)
+			gdouble           *dpi_x,
+			gdouble           *dpi_y)
 {
 	GtkPageSetup *page_setup;
 	GtkPaperSize *paper_size;
 
 	page_setup = gtk_print_context_get_page_setup (preview->context);
 
-	/* gtk_page_setup_get_paper_size swaps width and height for landscape */
+	/* Note: gtk_page_setup_get_paper_size() swaps width and height for
+	 * landscape.
+	 */
 	paper_size = gtk_page_setup_get_paper_size (page_setup);
 
 	return create_preview_surface_platform (paper_size, dpi_x, dpi_y);
 }
 
 GtkWidget *
-gedit_print_preview_new (GtkPrintOperation        *op,
+gedit_print_preview_new (GtkPrintOperation        *operation,
 			 GtkPrintOperationPreview *gtk_preview,
 			 GtkPrintContext          *context)
 {
 	GeditPrintPreview *preview;
-	GtkPageSetup *page_setup;
 	cairo_surface_t *surface;
 	cairo_t *cr;
-	double dpi_x, dpi_y;
+	gdouble dpi_x, dpi_y;
 
-	g_return_val_if_fail (GTK_IS_PRINT_OPERATION (op), NULL);
+	g_return_val_if_fail (GTK_IS_PRINT_OPERATION (operation), NULL);
 	g_return_val_if_fail (GTK_IS_PRINT_OPERATION_PREVIEW (gtk_preview), NULL);
 
 	preview = g_object_new (GEDIT_TYPE_PRINT_PREVIEW, NULL);
 
-	preview->operation = g_object_ref (op);
+	preview->operation = g_object_ref (operation);
 	preview->gtk_preview = g_object_ref (gtk_preview);
 	preview->context = g_object_ref (context);
 
 	/* FIXME: is this legal?? */
-	gtk_print_operation_set_unit (op, GTK_UNIT_POINTS);
+	gtk_print_operation_set_unit (operation, GTK_UNIT_POINTS);
 
-	g_signal_connect (gtk_preview, "ready",
-			  G_CALLBACK (preview_ready), preview);
-	g_signal_connect (gtk_preview, "got-page-size",
-			  G_CALLBACK (preview_got_page_size), preview);
-
-	page_setup = gtk_print_context_get_page_setup (preview->context);
-	update_paper_size (preview, page_setup);
+	g_signal_connect_object (gtk_preview,
+				 "ready",
+				 G_CALLBACK (preview_ready),
+				 preview,
+				 0);
 
 	/* FIXME: we need a cr to paginate... but we can't get the drawing
 	 * area surface because it's not there yet... for now I create
-	 * a dummy pdf surface */
-
+	 * a dummy pdf surface.
+	 * gtk_print_context_set_cairo_context() should be called in the
+	 * got-page-size handler.
+	 */
 	surface = create_preview_surface (preview, &dpi_x, &dpi_y);
 	cr = cairo_create (surface);
 	gtk_print_context_set_cairo_context (context, cr, dpi_x, dpi_y);
