@@ -24,23 +24,24 @@
 #include <gtk/gtk.h>
 #include "gedit-document.h"
 #include "gedit-view.h"
+#include "gedit-view-holder.h"
 
 G_BEGIN_DECLS
 
 #define GEDIT_TYPE_VIEW_FRAME (gedit_view_frame_get_type ())
 G_DECLARE_FINAL_TYPE (GeditViewFrame, gedit_view_frame, GEDIT, VIEW_FRAME, GtkOverlay)
 
-GeditViewFrame	*gedit_view_frame_new		(void);
+GeditViewFrame	*gedit_view_frame_new			(void);
 
-GeditDocument	*gedit_view_frame_get_document	(GeditViewFrame *frame);
+GeditViewHolder	*gedit_view_frame_get_view_holder	(GeditViewFrame *frame);
 
-GeditView	*gedit_view_frame_get_view	(GeditViewFrame *frame);
+GeditView	*gedit_view_frame_get_view		(GeditViewFrame *frame);
 
-void		 gedit_view_frame_popup_search	(GeditViewFrame *frame);
+void		 gedit_view_frame_popup_search		(GeditViewFrame *frame);
 
-void		 gedit_view_frame_popup_goto_line (GeditViewFrame *frame);
+void		 gedit_view_frame_popup_goto_line	(GeditViewFrame *frame);
 
-void		 gedit_view_frame_clear_search	(GeditViewFrame *frame);
+void		 gedit_view_frame_clear_search		(GeditViewFrame *frame);
 
 G_END_DECLS
 
