@@ -21,6 +21,7 @@
 #ifndef __GEDIT_WINDOW_H__
 #define __GEDIT_WINDOW_H__
 
+#include <gtksourceview/gtksource.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 
@@ -79,20 +80,20 @@ GType 		 gedit_window_get_type 			(void) G_GNUC_CONST;
 GeditTab	*gedit_window_create_tab		(GeditWindow         *window,
 							 gboolean             jump_to);
 
-GeditTab	*gedit_window_create_tab_from_location	(GeditWindow         *window,
-							 GFile               *location,
-							 const GeditEncoding *encoding,
-							 gint                 line_pos,
-							 gint                 column_pos,
-							 gboolean             create,
-							 gboolean             jump_to);
+GeditTab	*gedit_window_create_tab_from_location	(GeditWindow             *window,
+							 GFile                   *location,
+							 const GtkSourceEncoding *encoding,
+							 gint                     line_pos,
+							 gint                     column_pos,
+							 gboolean                 create,
+							 gboolean                 jump_to);
 
-GeditTab	*gedit_window_create_tab_from_stream	(GeditWindow         *window,
-							 GInputStream        *stream,
-							 const GeditEncoding *encoding,
-							 gint                 line_pos,
-							 gint                 column_pos,
-							 gboolean             jump_to);
+GeditTab	*gedit_window_create_tab_from_stream	(GeditWindow             *window,
+							 GInputStream            *stream,
+							 const GtkSourceEncoding *encoding,
+							 gint                     line_pos,
+							 gint                     column_pos,
+							 gboolean                 jump_to);
 
 void		 gedit_window_close_tab			(GeditWindow         *window,
 							 GeditTab            *tab);
