@@ -98,22 +98,24 @@ struct _GeditFileBrowserStoreClass {
 	GObjectClass parent_class;
 
 	/* Signals */
-	void (* begin_loading)	(GeditFileBrowserStore *model,
-				 GtkTreeIter           *iter);
-	void (* end_loading)	(GeditFileBrowserStore *model,
-				 GtkTreeIter           *iter);
-	void (* error)		(GeditFileBrowserStore *model,
-				 guint                  code,
-				 gchar                 *message);
-	gboolean (* no_trash)	(GeditFileBrowserStore *model,
-				 GList                 *files);
-	void (* rename)		(GeditFileBrowserStore *model,
-				 GFile                 *oldfile,
-				 GFile                *newfile);
-	void (* begin_refresh)	(GeditFileBrowserStore *model);
-	void (* end_refresh)	(GeditFileBrowserStore *model);
-	void (* unload)		(GeditFileBrowserStore *model,
-				 GFile                *location);
+	void (* begin_loading)      (GeditFileBrowserStore *model,
+	                             GtkTreeIter           *iter);
+	void (* end_loading)        (GeditFileBrowserStore *model,
+	                             GtkTreeIter           *iter);
+	void (* error)              (GeditFileBrowserStore *model,
+	                             guint                  code,
+	                             gchar                 *message);
+	gboolean (* no_trash)       (GeditFileBrowserStore *model,
+	                             GList                 *files);
+	void (* rename)             (GeditFileBrowserStore *model,
+	                             GFile                 *oldfile,
+	                             GFile                 *newfile);
+	void (* begin_refresh)      (GeditFileBrowserStore *model);
+	void (* end_refresh)        (GeditFileBrowserStore *model);
+	void (* unload)             (GeditFileBrowserStore *model,
+	                             GFile                 *location);
+	void (* before_row_deleted) (GeditFileBrowserStore *model,
+	                             GtkTreePath           *path);
 };
 
 GType		 gedit_file_browser_store_get_type		(void) G_GNUC_CONST;
