@@ -2,8 +2,8 @@
 #define __GEDIT_FILE_BROWER_MESSAGES_MESSAGES_H__
 
 #include "gedit-file-browser-message-activation.h"
-#include "gedit-file-browser-message-add-context-item.h"
 #include "gedit-file-browser-message-add-filter.h"
+#include "gedit-file-browser-message-extend-context-menu.h"
 #include "gedit-file-browser-message-get-root.h"
 #include "gedit-file-browser-message-get-view.h"
 #include "gedit-file-browser-message-id.h"
